#ifndef DEFINE_ISLIB_SIGMOID_HPP

#define DEFINE_ISLIB_SIGMOID_HPP

namespace islib
  {
    //
    // Declaration of function
    //
    double sigmoid ( double );
  }

#endif // DEFINE_ISLIB_SIGMOID_HPP

//
// End of file
//
